**************************
The sherpa.ui.utils module
**************************

.. currentmodule:: sherpa.ui.utils

.. automodule:: sherpa.ui.utils

The :py:mod:`sherpa.ui.utils` module contains the
:py:class:`~sherpa.ui.utils.Session` class that
provides the data-management code used by the
:py:mod:`sherpa.ui` module.
                
   .. rubric:: Classes
               
   .. autosummary::
      :toctree: api

      ModelWrapper
      Session
      
Class Inheritance Diagram
=========================

.. inheritance-diagram:: ModelWrapper Session
   :parts: 1
